@@ -1,5 +1,5 @@
 /*
- *  $Id: Config.h,v 1.11 2004/07/03 21:42:45 rousseau Exp $
+ *  $Id: Config.h,v 1.12 2005/06/17 10:37:38 rousseau Exp $
  *  ifd-GemPC410
  *
  *  Created by JL Giraud <jl.giraud@free.fr> on Sun Nov 19 2000.
@@ -11,20 +11,6 @@
 #ifndef __CONFIG_H__
 #define __CONFIG_H__
 
-/* Define debug levels here */
-
-/* Critical informations. Should always be active */
-#define DEBUG_LEVEL_CRITICAL
-
-/* Normal debug info */
-#define DEBUG_LEVEL_INFO
-
-/* periodic info: messages caused by pcsclite scanning every second */
-/* #define DEBUG_LEVEL_PERIODIC */
-
-/* low level communications */
-/* #define DEBUG_LEVEL_COMM */
-
 /* Perform automatic PPS negociation
  * unsed by default for safety instead of speed */
 /* #define AUTOMATIC_PPS */
