@@ -19,9 +19,10 @@
  */
 
 /*
- * $Id: gbpserial.c,v 1.36 2004/07/03 21:11:42 rousseau Exp $
+ * $Id: gbpserial.c,v 1.37 2005/06/17 10:38:47 rousseau Exp $
  */
 
+#include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -146,12 +147,9 @@ RESPONSECODE WriteGBP(DWORD lun, DWORD length, PUCHAR buffer)
 	UCHAR edc;
 	int reader = LunToReaderIndex(lun);
 	UCHAR *gbpbuffer = GbpBuffer[reader];
-#ifdef DEBUG_LEVEL_COMM
 	char debug_header[] = "-> 121234 ";
 
 	sprintf(debug_header, "-> %06X ", (int)lun);
-#endif
-
 
 	/* PDU length = length + NAD + PCB + LEN */
 	len = length + 3;
@@ -176,9 +174,7 @@ RESPONSECODE WriteGBP(DWORD lun, DWORD length, PUCHAR buffer)
 	/* increment Seq: 0 -> 1 or 1 -> 0 */
 	gbpDevice[reader].bSeq = (gbpDevice[reader].bSeq + 1) % 2;
 
-#ifdef DEBUG_LEVEL_COMM
 	DEBUG_XXD(debug_header, gbpbuffer, len);
-#endif
 	rv = write(gbpDevice[reader].fd, gbpbuffer, len);
 
 	if (rv < 0)
@@ -208,11 +204,9 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
 	fd_set fdset;
 	int fd = gbpDevice[reader].fd;
 	struct timeval t;
-#ifdef DEBUG_LEVEL_COMM
 	char debug_header[] = "<- 121234 ";
 
 	sprintf(debug_header, "<- %06X ", (int)lun);
-#endif
 
 	len = sizeof(GbpBuffer[reader]);
 	buffer_size = *length;
@@ -246,10 +240,8 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
 	/* too short */
 	if (rv < 4)
 	{
-#ifdef DEBUG_LEVEL_COMM
 		DEBUG_XXD(debug_header, gbpbuffer, rv);
 		ExplainGBP(gbpbuffer, rv);
-#endif
 		DEBUG_COMM2("only %d byte(s) read", rv);
 
 		return STATUS_UNSUCCESSFUL;
@@ -258,10 +250,8 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
 	/* NAD byte */
 	if ((gbpbuffer[NAD] != NAD_IFD2HOST) && (gbpbuffer[NAD] != NAD_XXX2HOST))
 	{
-#ifdef DEBUG_LEVEL_COMM
 		DEBUG_XXD(debug_header, gbpbuffer, rv);
 		ExplainGBP(gbpbuffer, rv);
-#endif
 		DEBUG_COMM2("wrong NAD byte 0x%02X", gbpbuffer[NAD]);
 
 		return STATUS_NAD_UNKNOWN;
@@ -274,9 +264,7 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
 	{
 		int ret;
 
-#ifdef DEBUG_LEVEL_COMM
 		DEBUG_XXD(debug_header, gbpbuffer, rv);
-#endif
 		ret = ExplainGBP(gbpbuffer, rv);
 		DEBUG_COMM("PCB error");
 
@@ -309,9 +297,7 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
 		else
 			if (i == 0)
 			{
-#ifdef DEBUG_LEVEL_COMM
 				DEBUG_XXD(debug_header, gbpbuffer, already_read);
-#endif
 				DEBUG_COMM2("Timeout! (%d sec)", SERIAL_TIMEOUT);
 				return STATUS_UNSUCCESSFUL;
 			}
@@ -319,9 +305,7 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
 		rv = read(fd, gbpbuffer + already_read, len);
 		if (rv < 0)
 		{
-#ifdef DEBUG_LEVEL_COMM
 			DEBUG_XXD(debug_header, gbpbuffer, already_read);
-#endif
 			DEBUG_COMM2("read error: %s", strerror(errno));
 			return STATUS_UNSUCCESSFUL;
 		}
@@ -335,9 +319,7 @@ RESPONSECODE ReadGBP(DWORD lun, PDWORD length, PUCHAR buffer)
 	for (i = 0; i < to_read; i++)
 		edc ^= gbpbuffer[i];
 
-#ifdef DEBUG_LEVEL_COMM
 	DEBUG_XXD(debug_header, gbpbuffer, to_read);
-#endif
 
 	/* verify checksum */
 	if (edc != 0)
