@@ -18,7 +18,7 @@
 */
 
 /*
- * $Id: resetGemPC410.c,v 1.9 2002/09/08 13:45:38 rousseau Exp $
+ * $Id: resetGemPC410.c,v 1.10 2004/07/03 21:42:45 rousseau Exp $
  */
 
 #include <errno.h>
@@ -61,51 +61,51 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
-	// The serial port is not yet configured to 38400 bauds?
+	/* The serial port is not yet configured to 38400 bauds? */
 	if (cfgetospeed(&current_termios) != B38400)
 	{
 		printf("actual baud rate: %d\n", cfgetospeed(&current_termios));
 
 		current_termios.c_iflag = 0;
-		current_termios.c_oflag = 0;	// Raw output modes
-		current_termios.c_cflag = 0;	// Raw output modes
+		current_termios.c_oflag = 0;	/* Raw output modes */
+		current_termios.c_cflag = 0;	/* Raw output modes */
 
-		// Do not echo characters because if you connect
-		// to a host it or your
-		// modem will echo characters for you.
-		// Don't generate signals.
+		/* Do not echo characters because if you connect
+		 * to a host it or your
+		 * modem will echo characters for you.
+		 * Don't generate signals. */
 		current_termios.c_lflag = 0;
 
-		// control flow - enable receiver - ignore modem
-		// control lines
+		/* control flow - enable receiver - ignore modem
+		 * control lines */
 		current_termios.c_cflag = CREAD | CLOCAL;
 
-		// default speed is 38400 bauds
+		/* default speed is 38400 bauds */
 		cfsetospeed(&current_termios, B38400);
 		cfsetispeed(&current_termios, 0); /* 0 corresponds to output speed */
 
 		current_termios.c_cflag |= CS8;
 
-		//case ODDPARITY:
-		//current_termios.c_cflag |= PARENB + PARODD;
-		//case EVENPARITY:
-		//current_termios.c_cflag |= PARENB;
+		/*case ODDPARITY:
+		 *current_termios.c_cflag |= PARENB + PARODD;
+		 *case EVENPARITY:
+		 *current_termios.c_cflag |= PARENB;
 
-		// control caracteres
+		 * control caracteres
 
-		// Minimum bytes to read
-		// current_termios.c_cc[VMIN]  = 0;
-		// Time between two bytes read (VTIME x 0.10 s)
-		// current_termios.c_cc[VTIME] = 0;
+		 * Minimum bytes to read
+		 * current_termios.c_cc[VMIN]  = 0;
+		 * Time between two bytes read (VTIME x 0.10 s)
+		 * current_termios.c_cc[VTIME] = 0;
 
-		// This is Non Canonical mode set.
-		// by setting c_cc[VMIN]=0 and c_cc[VTIME] = 10
-		// each read operation will wait for 10*/10=1sec
-		// If single byte is received, read function returns.
-		// if timer expires, read() returns 0.
-		// Minimum bytes to read
+		 * This is Non Canonical mode set.
+		 * by setting c_cc[VMIN]=0 and c_cc[VTIME] = 10
+		 * each read operation will wait for 10/10 = 1 sec
+		 * If single byte is received, read function returns.
+		 * if timer expires, read() returns 0.
+		 * Minimum bytes to read */
 		current_termios.c_cc[VMIN] = 0;
-		// Time between two bytes read (VTIME x 0.10 s)
+		/* Time between two bytes read (VTIME x 0.10 s) */
 		current_termios.c_cc[VTIME] = 20;
 
 		printf("Set serial port baudrate to 38400\n");
@@ -122,20 +122,20 @@ int main(int argc, char *argv[])
 		printf("port " DEVICE " already at 38400 bauds\n");
 	}
 
-	cmd[0] = 0x42; // NAD
-	cmd[1] = 0x00; // PCB
-	cmd[2] = 0x05; // LEN
-	cmd[3] = 0x22; // Read Firmware Version
+	cmd[0] = 0x42; /* NAD */
+	cmd[1] = 0x00; /* PCB */
+	cmd[2] = 0x05; /* LEN */
+	cmd[3] = 0x22; /* Read Firmware Version */
 	cmd[4] = 0x05;
 	cmd[5] = 0x3F;
 	cmd[6] = 0xE0;
 	cmd[7] = 0x10;
-	cmd[8] = 0x00; // EDC
+	cmd[8] = 0x00; /* EDC */
 	checksum(cmd, 9);
 
 	printf("-> ");
 	debug(cmd, 9);
-	//explain_gbp(cmd, 9);
+	/* explain_gbp(cmd, 9); */
 
 	if (write(fd, cmd, 9) < 0)
 	{
@@ -161,7 +161,7 @@ int main(int argc, char *argv[])
 
 		current_termios.c_cflag = CREAD | CLOCAL;
 
-		// default speed is 9600 bauds
+		/* default speed is 9600 bauds */
 		current_termios.c_cflag |= B9600;
 		current_termios.c_cflag |= CS8;
 
@@ -182,7 +182,7 @@ int main(int argc, char *argv[])
 
 	printf("-> ");
 	debug(cmd, 9);
-	//explain_gbp(cmd, 9);
+	/* explain_gbp(cmd, 9); */
 
 	if (write(fd, cmd, 9) < 0)
 	{
@@ -199,14 +199,14 @@ int main(int argc, char *argv[])
 	explain_gbp(buffer, rv);
 
 	/* reset GemCore */
-	cmd[0] = 0x42; // NAD
-	cmd[1] = 0x00; // PCB
-	cmd[2] = 0x04; // LEN
-	cmd[3] = 0x0C; // Restart
+	cmd[0] = 0x42; /* NAD */
+	cmd[1] = 0x00; /* PCB */
+	cmd[2] = 0x04; /* LEN */
+	cmd[3] = 0x0C; /* Restart */
 	cmd[4] = 0x00;
 	cmd[5] = 0x00;
 	cmd[6] = 0x00;
-	cmd[7] = 0x00; // EDC
+	cmd[7] = 0x00; /* EDC */
 	checksum(cmd, 8);
 
 	printf("-> ");
@@ -235,7 +235,7 @@ void checksum(unsigned char cmd[], const int len)
 {
 	int edc, i;
 
-	// checksum
+	/* checksum */
 	edc = 0;
 	for (i=0; i<len-1; i++)
 		edc ^= cmd[i];
@@ -439,20 +439,20 @@ int multi_read(int fd, unsigned char *buf, size_t count)
 	if (rv < 0)
 		return rv;
 
-	// too short
+	/* too short */
 	if (rv < 3)
 	{
 		printf("ReadGBP: only %d byte(s) read\n", rv);
 		return rv;
 	}
 
-	// LEN byte (+4 bytes of protocol)
+	/* LEN byte (+4 bytes of protocol) */
 	to_read = buf[2]+4;
 
-	// Nb of bytes already read
+	/* Nb of bytes already read */
 	already_read = rv;
 
-	// Nb of bytes until the end of the buffer
+	/* Nb of bytes until the end of the buffer */
 	len = count - rv;
 
 	while (already_read < to_read)
