@@ -1,6 +1,6 @@
 /*
  *  GemPC430Utils.h
- *  $Id: GemPC430Utils.h,v 1.6 2004/01/20 13:42:15 rousseau Exp $
+ *  $Id: GemPC430Utils.h,v 1.7 2004/07/03 21:11:44 rousseau Exp $
  *  GemPC430 dedicated functions
  *
  *  Created by giraud on Sat Oct 20 2001.
@@ -12,7 +12,7 @@
 #ifndef _GEMPC430UTILS_H_
 #define _GEMPC430UTILS_H_
 
-ifd_t OpenGemPC430ByName(DWORD lun, LPSTR dev_name);
+ifd_t OpenGemPC430ByName(DWORD lun, LPTSTR dev_name);
 ifd_t OpenGemPC430(DWORD lun, DWORD channel);
 ifd_t CloseGemPC430(DWORD lun);
 
