@@ -11,10 +11,10 @@
 #ifndef _LIBUSB_WRAP_
 #define _LIBUSB_WRAP_
 
-gcore_t OpenUSB( DWORD lun, LPSTR device );
-gcore_t WriteUSB( DWORD lun, DWORD length, unsigned char *Buffer );
-gcore_t ReadUSB( DWORD lun, DWORD *length, unsigned char *Buffer );
-gcore_t CloseUSB( DWORD lun );
+status_t OpenUSB( DWORD lun, LPTSTR device );
+status_t WriteUSB( DWORD lun, DWORD length, unsigned char *Buffer );
+status_t ReadUSB( DWORD lun, DWORD *length, unsigned char *Buffer );
+status_t CloseUSB( DWORD lun );
 
 #endif
 
