@@ -1,5 +1,5 @@
 /*
- * $Id: GCdebug.c,v 1.7 2005/06/17 10:20:43 rousseau Exp $
+ * $Id: GCdebug.c,v 1.8 2006-02-09 13:29:35 rousseau Exp $
  * GCdebug.c: log (or not) messages
  * Copyright (C) 2001 Ludovic Rousseau <ludovic.rousseau@free.fr>
  * 
@@ -34,7 +34,7 @@ void log_xxd(const int priority, const char *msg, const unsigned char *buffer,
 	const int len)
 {
 	int i;
-	unsigned char *c, *debug_buf_end;
+	char *c, *debug_buf_end;
 
 	debug_buf_end = DebugBuffer + DEBUG_BUF_SIZE - 5;
 
