@@ -13,7 +13,7 @@
 /            See http://www.linuxnet.com for more information.
 / License:   See file COPYING.BSD
 /
-/ $Id: ifdhandler.c,v 1.25 2004/07/24 14:31:04 rousseau Exp $
+/ $Id: ifdhandler.c,v 1.26 2006-02-09 13:29:35 rousseau Exp $
 /
 ******************************************************************/
 
@@ -449,7 +449,7 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 				/* just (CLA, INS, P1, P2) for an APDU */
 				if (TxLength == ISO_CMD_SIZE)
 				{
-					char cmd[ISO_CMD_SIZE + ISO_LENGTH_SIZE];
+					unsigned char cmd[ISO_CMD_SIZE + ISO_LENGTH_SIZE];
 
 					/* copy CLA, INS, P1, P2 */
 					memcpy(cmd, TxBuffer, ISO_CMD_SIZE);
